package service

import (
	"context"
	"github.com/go-kratos/kratos/v2/log"
	"hilo/app/service/demo/internal/dao"
	"hilo/app/service/demo/internal/model"
)

// DemoUseService is a Demo service.
type DemoUseService struct {
	dao *dao.Dao
	log *log.Helper
}

type ListReq struct {
	Page int
	Size int
}

// NewDemoService new a Demo service.
func NewDemoService(dao *dao.Dao) *DemoUseService {
	return &DemoUseService{
		dao: dao,
		log: log.NewHelper(log.GetLogger()),
	}
}

func (s *DemoUseService) CreateDemo(ctx context.Context, m *model.Demo) error {
	return s.dao.Save(ctx, m)
}

func (s *DemoUseService) UpdateDemo(ctx context.Context, m *model.Demo) error {
	return s.dao.Update(ctx, m)
}

func (s *DemoUseService) GetDemo(ctx context.Context, id int) (*model.Demo, error) {
	s.log.WithContext(ctx).Info("qqqqqqqqqqqqqqqq")

	m, err := s.dao.GetByID(ctx, id)
	if err != nil {
		return nil, err
	}

	return m, nil

}

func (s *DemoUseService) ListDemo(ctx context.Context, req *ListReq) ([]*model.Demo, error) {
	if req.Page <= 0 {
		req.Page = 1
	}

	if req.Size <= 0 {
		req.Size = 20
	}

	if req.Size >= 100 {
		req.Size = 100
	}

	offset := (req.Page - 1) * req.Size

	return s.dao.List(ctx, req.Size, offset)
}

func (s *DemoUseService) DeleteDemo(ctx context.Context, id int) error {
	return s.dao.DeleteByID(ctx, int(id))
}
